@@ -3,7 +3,7 @@ package Validator::LIVR::Rules::String;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '2.0';
 
 sub one_of {
     my $allowed_values;
@@ -16,11 +16,18 @@ sub one_of {
 
 
     return sub {
-        my $value = shift;
+        my ($value, undef, $output_ref) = @_;
         return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value) && ref($value) !~ 'Boolean';
 
-        return 'NOT_ALLOWED_VALUE' unless grep { $value eq $_ } @$allowed_values;
-        return;
+        for my $allowed_value (@$allowed_values) {
+            if ($value eq $allowed_value) {
+                $$output_ref = $allowed_value;
+                return;
+            }
+        }
+
+        return 'NOT_ALLOWED_VALUE';
     }
 }
 
@@ -31,6 +38,7 @@ sub max_length {
     return sub {
         my $value = shift;
         return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value);
 
         return 'TOO_LONG' if length($value) > $max_length;
         return;
@@ -44,6 +52,7 @@ sub min_length {
     return sub {
         my $value = shift;
         return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value);
 
         return 'TOO_SHORT' if length($value) < $min_length;
         return;
@@ -57,6 +66,7 @@ sub length_equal {
     return sub {
         my $value = shift;
         return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value);
 
         return 'TOO_SHORT' if length($value) < $length;
         return 'TOO_LONG' if length($value) > $length;
@@ -71,6 +81,7 @@ sub length_between {
     return sub {
         my $value = shift;
         return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value);
 
         return 'TOO_SHORT' if length($value) < $min_length;
         return 'TOO_LONG' if length($value) > $max_length;
@@ -88,10 +99,37 @@ sub like {
     return sub {
         my $value = shift;
         return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value);
 
         return 'WRONG_FORMAT' unless $value =~  m/$re/;
         return;
     };
 }
 
-1;
\ No newline at end of file
+
+sub string {
+    return sub {
+        my $value = shift;
+
+        return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value);
+        return;
+    };
+}
+
+
+sub equal {
+    my $allowed_value = shift;
+
+    return sub {
+        my ($value, undef, $output_ref) = @_;
+        return if !defined($value) || $value eq '';
+        return 'FORMAT_ERROR' if ref($value);
+
+        return if $value eq $allowed_value;
+
+        return 'NOT_ALLOWED_VALUE';
+    };
+}
+
+1;
